@@ -8,18 +8,18 @@ makeRLearner.classif.lqa = function() {
         values = c("adaptive.lasso", "ao", "bridge", "enet", "fused.lasso", "genet", "icb", "lasso",
           "licb", "oscar", "penalreg", "ridge", "scad", "weighted.fusion")),
       makeNumericLearnerParam(id = "lambda", lower = 0,
-        requires = expression(penalty %in% c("adaptive.lasso", "ao", "bridge", "genet", "lasso",
+        requires = quote(penalty %in% c("adaptive.lasso", "ao", "bridge", "genet", "lasso",
           "oscar", "penalreg", "ridge", "scad"))),
       makeNumericLearnerParam(id = "gamma", lower = 1 + .Machine$double.eps,
-        requires = expression(penalty %in% c("ao", "bridge", "genet", "weighted.fusion"))),
-      makeNumericLearnerParam(id = "alpha", lower = 0, requires = expression(penalty == "genet")),
-      makeNumericLearnerParam(id = "c", lower = 0, requires = expression(penalty == "oscar")),
+        requires = quote(penalty %in% c("ao", "bridge", "genet", "weighted.fusion"))),
+      makeNumericLearnerParam(id = "alpha", lower = 0, requires = quote(penalty == "genet")),
+      makeNumericLearnerParam(id = "c", lower = 0, requires = quote(penalty == "oscar")),
       makeNumericLearnerParam(id = "a", lower = 2 + .Machine$double.eps,
-        requires = expression(penalty == "scad")),
+        requires = quote(penalty == "scad")),
       makeNumericLearnerParam(id = "lambda1", lower = 0,
-        requires = expression(penalty %in% c("enet", "fused.lasso", "icb", "licb", "weighted.fusion"))),
+        requires = quote(penalty %in% c("enet", "fused.lasso", "icb", "licb", "weighted.fusion"))),
       makeNumericLearnerParam(id = "lambda2", lower = 0,
-        requires = expression(penalty %in% c("enet", "fused.lasso", "icb", "licb", "weighted.fusion"))),
+        requires = quote(penalty %in% c("enet", "fused.lasso", "icb", "licb", "weighted.fusion"))),
       makeDiscreteLearnerParam(id = "method", default = "lqa.update2",
         values = c("lqa.update2", "ForwardBoost", "GBlockBoost")),
       makeNumericLearnerParam(id = "var.eps", default = .Machine$double.eps, lower = 0),
