@@ -9,12 +9,16 @@ makeRLearner.regr.km = function() {
       makeNumericLearnerParam(id = "nugget"),
       makeLogicalLearnerParam(id = "nugget.estim", default = FALSE),
       makeNumericVectorLearnerParam(id = "noise.var"),
+      makeDiscreteLearnerParam(id = "estim.method", default = "MLE",
+        values = c("MLE", "LOO")),
       makeDiscreteLearnerParam(id = "optim.method", default = "BFGS",
-        values = list("BFGS", "gen")),
+        values = c("BFGS", "gen")),
       makeNumericVectorLearnerParam(id = "lower"),
       makeNumericVectorLearnerParam(id = "upper"),
       makeUntypedLearnerParam(id = "control"),
+      makeLogicalLearnerParam(id = "gr", default = TRUE),
       makeLogicalLearnerParam(id = "iso", default = FALSE),
+      makeLogicalLearnerParam(id = "scaling", default = FALSE),
       makeLogicalLearnerParam(id = "jitter", default = FALSE, when = "predict")
     ),
     par.vals = list(jitter = FALSE),
