@@ -9,23 +9,25 @@ makeRLearner.regr.ksvm = function() {
       makeDiscreteLearnerParam(id = "kernel", default = "rbfdot",
         values = c("vanilladot", "polydot", "rbfdot", "tanhdot", "laplacedot", "besseldot", "anovadot", "splinedot", "stringdot")),
       makeNumericLearnerParam(id = "C",
-        lower = 0, default = 1, requires = expression(type %in% c("eps-svr", "eps-bsvr"))),
+        lower = 0, default = 1, requires = quote(type %in% c("eps-svr", "eps-bsvr"))),
       makeNumericLearnerParam(id = "nu",
-        lower = 0, default = 0.2, requires = expression(type == "nu-svr")),
-      makeNumericLearnerParam(id = "epsilon", lower = 0, default = 0.1),
+        lower = 0, default = 0.2, requires = quote(type == "nu-svr")),
+      makeNumericLearnerParam(id = "epsilon", lower = 0, default = 0.1,
+        requires = quote(type %in% c("eps-svr", "nu-svr", "eps-bsvm"))),
       makeNumericLearnerParam(id = "sigma",
-        lower = 0, requires = expression(kernel %in% c("rbfdot", "anovadot", "besseldot", "laplacedot"))),
+        lower = 0, requires = quote(kernel %in% c("rbfdot", "anovadot", "besseldot", "laplacedot"))),
       makeIntegerLearnerParam(id = "degree", default = 3L, lower = 1L,
-        requires = expression(kernel %in% c("polydot", "anovadot", "besseldot"))),
+        requires = quote(kernel %in% c("polydot", "anovadot", "besseldot"))),
       makeNumericLearnerParam(id = "scale", default = 1, lower = 0,
-        requires = expression(kernel %in% c("polydot", "tanhdot"))),
+        requires = quote(kernel %in% c("polydot", "tanhdot"))),
       makeNumericLearnerParam(id = "offset", default = 1,
-        requires = expression(kernel %in% c("polydot", "tanhdot"))),
+        requires = quote(kernel %in% c("polydot", "tanhdot"))),
       makeIntegerLearnerParam(id = "order", default = 1L,
-        requires = expression(kernel == "besseldot")),
+        requires = quote(kernel == "besseldot")),
       makeNumericLearnerParam(id = "tol", default = 0.001, lower = 0),
       makeLogicalLearnerParam(id = "shrinking", default = TRUE),
-      makeLogicalLearnerParam(id = "fit", default = TRUE)
+      makeLogicalLearnerParam(id = "fit", default = TRUE),
+      makeIntegerLearnerParam(id = "cache", default = 40L, lower = 1L, tunable = FALSE)
     ),
     par.vals = list(fit = FALSE),
     properties = c("numerics", "factors"),
