@@ -9,22 +9,24 @@ makeRLearner.regr.rvm = function() {
         values = c("vanilladot", "polydot", "rbfdot", "tanhdot", "laplacedot", "besseldot", "anovadot", "splinedot", "stringdot")),
       makeNumericLearnerParam(id = "tau", lower = 0, default = 0.01),
       makeNumericLearnerParam(id = "sigma",
-        lower = 0, requires = expression(kernel %in% c("rbfdot", "anovadot", "besseldot", "laplacedot"))),
+        lower = 0, requires = quote(kernel %in% c("rbfdot", "anovadot", "besseldot", "laplacedot"))),
       makeIntegerLearnerParam(id = "degree", default = 3L, lower = 1L,
-        requires = expression(kernel %in% c("polydot", "anovadot", "besseldot"))),
+        requires = quote(kernel %in% c("polydot", "anovadot", "besseldot"))),
       makeNumericLearnerParam(id = "scale", default = 1, lower = 0,
-        requires = expression(kernel %in% c("polydot", "tanhdot"))),
+        requires = quote(kernel %in% c("polydot", "tanhdot"))),
       makeNumericLearnerParam(id = "offset", default = 1,
-        requires = expression(kernel %in% c("polydot", "tanhdot"))),
+        requires = quote(kernel %in% c("polydot", "tanhdot"))),
       makeNumericLearnerParam(id = "order", default = 1L,
-        requires = expression(kernel == "besseldot")),
+        requires = quote(kernel == "besseldot")),
       makeNumericLearnerParam(id = "alpha", default = 5L, lower = 0L),
       makeNumericLearnerParam(id = "var", default = 0.1, lower = 0),
       makeLogicalLearnerParam(id = "var.fix", default = FALSE),
       makeNumericLearnerParam(id = "iterations", default = 100L, lower = 0L),
       makeNumericLearnerParam(id = "tol", default = .Machine$double.eps, lower = 0),
       makeNumericLearnerParam(id = "minmaxdiff", default = 0.001, lower = 0),
-      makeLogicalLearnerParam(id = "fit", default = TRUE)
+      makeLogicalLearnerParam(id = "verbosity", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "fit", default = TRUE),
+      makeIntegerLearnerParam(id = "cross", default = 0L, lower = 0L)
     ),
     par.vals = list(fit = FALSE),
     properties = c("numerics", "factors"),
