@@ -6,14 +6,18 @@ makeRLearner.surv.CoxBoost = function() {
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "maxstepno", default = 100, lower = 0),
       makeIntegerLearnerParam(id = "K", default = 10, lower = 1),
-      makeDiscreteLearnerParam(id = "type", default = "verweij", values = c("verweij", "naive")),
+      makeDiscreteLearnerParam(id = "type", default = "verweij",
+        values = c("verweij", "naive")),
       makeIntegerLearnerParam(id = "stepno", default = 100L, lower = 1),
       makeNumericLearnerParam(id = "penalty", lower = 0),
       makeLogicalLearnerParam(id = "standardize", default = TRUE),
-      makeDiscreteLearnerParam(id = "criterion", default = "pscore", values = c("pscore", "score", "hpscore", "hscore")),
+      makeDiscreteLearnerParam(id = "criterion", default = "pscore",
+        values = c("pscore", "score", "hpscore", "hscore")),
       makeNumericLearnerParam(id = "stepsize.factor", default = 1, lower = 0),
-      makeDiscreteLearnerParam(id = "sf.scheme", default = "sigmoid", values = c("sigmoid", "linear")),
-      makeLogicalLearnerParam(id = "return.score", default = TRUE)
+      makeDiscreteLearnerParam(id = "sf.scheme", default = "sigmoid",
+        values = c("sigmoid", "linear")),
+      makeLogicalLearnerParam(id = "return.score", default = TRUE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "trace", default = FALSE, tunable = FALSE)
     ),
     par.vals = list(return.score = FALSE),
     properties = c("numerics", "factors", "ordered", "weights", "rcens"),
