@@ -2,7 +2,7 @@
 makeRLearner.surv.glmboost = function() {
   makeRLearnerSurv(
     cl = "surv.glmboost",
-    package = c("survival", "mboost"),
+    package = c("!survival", "mboost"),
     par.set = makeParamSet(
       makeDiscreteLearnerParam(id = "family", default = mboost::CoxPH(), values = list(CoxPH = mboost::CoxPH(), Weibull = mboost::Weibull(), Loglog = mboost::Loglog(), Lognormal = mboost::Lognormal())),
       makeIntegerLearnerParam(id = "mstop", default = 100L, lower = 1L),
@@ -12,7 +12,7 @@ makeRLearner.surv.glmboost = function() {
       makeLogicalLearnerParam(id = "use.formula", default = TRUE, when = "both")
     ),
     par.vals = list(
-      family = "CoxPH",
+      family = mboost::CoxPH(),
       m = "mstop",
       use.formula = TRUE
     ),
@@ -29,10 +29,9 @@ makeRLearner.surv.glmboost = function() {
 #' @export
 trainLearner.surv.glmboost = function(.learner, .task, .subset, .weights = NULL, family, mstop, nu, m, use.formula, ...) {
   envir = loadNamespace("mboost")
-  family = do.call(get(family, mode = "function", envir = loadNamespace("mboost")), list())
   ctrl = learnerArgsToControl(mboost::boost_control, mstop, nu)
   if (use.formula) {
-    f = getTaskFormula(.task, env = loadNamespace("survival"))
+    f = getTaskFormula(.task)
     model = if (is.null(.weights)) {
       mboost::glmboost(f, data = getTaskData(.task, subset = .subset, recode.target = "rcens"), control = ctrl, family = family, ...)
     } else  {
