@@ -5,12 +5,22 @@ makeRLearner.surv.randomForestSRC = function() {
     package = c("survival", "randomForestSRC"),
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "ntree", default = 1000L, lower = 1L),
-      makeDiscreteLearnerParam(id = "bootstrap", values = c("by.root", "by.node", "none"), default = "by.root"),
+      makeDiscreteLearnerParam(id = "bootstrap", default = "by.root",
+        values = c("by.root", "by.node", "none")),
       makeIntegerLearnerParam(id = "mtry", lower = 1L),
       makeNumericLearnerParam(id = "mtry.ratio", lower = 0L, upper = 1L),
       makeIntegerLearnerParam(id = "nodesize", lower = 1L, default = 3L),
-      makeDiscreteLearnerParam(id = "splitrule", values = c("logrank", "logrankscore"), default = "logrank"),
-      makeDiscreteLearnerParam(id = "na.action", values = c("na.omit", "na.impute"), default = "na.impute", when = "both")
+      makeDiscreteLearnerParam(id = "splitrule", default = "logrank",
+        values = c("logrank", "logrankscore")),
+      makeDiscreteLearnerParam(id = "na.action", default = "na.impute",
+        values = c("na.omit", "na.impute"), when = "both"),
+      makeNumericVectorLearnerParam(id = "xwar.wt", lower = 0),
+      makeLogicalLearnerParam(id = "forest", default = TRUE, tunable = FALSE),
+      makeIntegerLearnerParam(id = "seed", tunable = FALSE),
+      makeLogicalLearnerParam(id = "do.trace", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "membership", default = TRUE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "statistics", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "fast.restore", default = FALSE, tunable = FALSE)
     ),
     par.vals = list(na.action = "na.impute"),
     properties = c("missings", "numerics", "factors", "ordered", "rcens"),
@@ -29,7 +39,7 @@ trainLearner.surv.randomForestSRC = function(.learner, .task, .subset, .weights
     mtry = mtry.ratio * nrow(data)
   }
 
-  f = getTaskFormula(.task, env = loadNamespace("survival"))
+  f = getTaskFormula(.task)
   randomForestSRC::rfsrc(f, data = data, importance = "none", proximity = FALSE, forest = TRUE,
     mtry = mtry, ...)
 }
