@@ -19,11 +19,25 @@
 #'   Performance measures for all tasks.
 #'   If missing, the default measure of the first task is used.
 #' @template arg_keep_pred
+#' @param models [\code{logical(1)}]\cr
+#'   Should all fitted models be stored in the \code{\link{ResampleResult}}?
+#'   Default is \code{TRUE}.
 #' @template arg_showinfo
 #' @return [\code{\link{BenchmarkResult}}].
 #' @family benchmark
 #' @export
-benchmark = function(learners, tasks, resamplings, measures, keep.pred = TRUE, show.info = getMlrOption("show.info")) {
+#' @examples
+#' lrns = list(makeLearner("classif.lda"), makeLearner("classif.rpart"))
+#' tasks = list(iris.task, sonar.task)
+#' rdesc = makeResampleDesc("CV", iters = 2L)
+#' meas = list(acc, ber)
+#' bmr = benchmark(lrns, tasks, rdesc, measures = meas)
+#' rmat = convertBMRToRankMatrix(bmr)
+#' print(rmat)
+#' plotBMRSummary(bmr)
+#' plotBMRBoxplots(bmr, ber, style = "violin")
+#' plotBMRRanksAsBarChart(bmr, pos = "stack")
+benchmark = function(learners, tasks, resamplings, measures, keep.pred = TRUE, models = TRUE, show.info = getMlrOption("show.info")) {
   learners = ensureVector(learners, 1L, "Learner")
   assertList(learners, min.len = 1L)
   checkListElementClass(learners, "Learner")
@@ -62,51 +76,73 @@ benchmark = function(learners, tasks, resamplings, measures, keep.pred = TRUE, s
 
   # check measures
   if (missing(measures)) {
-    measures = default.measures(tasks[[1L]])
+    measures = list(getDefaultMeasure(tasks[[1L]]))
   } else {
     measures = ensureVector(measures, 1L, "Measure")
     assertList(measures)
     checkListElementClass(measures, "Measure")
   }
+  assertFlag(models)
+  assertFlag(keep.pred)
 
-  inds = expand.grid(task = task.ids, learner = learner.ids, stringsAsFactors = FALSE)
-
+  grid = expand.grid(task = task.ids, learner = learner.ids, stringsAsFactors = FALSE)
   plevel = "mlr.benchmark"
   parallelLibrary("mlr", master = FALSE, level = plevel, show.info = FALSE)
   exportMlrOptions(level = "mlr.benchmark")
   results = parallelMap(
     benchmarkParallel,
-    split(as.matrix(inds), f = seq_row(inds)),
+    task = grid$task,
+    learner = grid$learner,
     more.args = list(learners = learners, tasks = tasks, resamplings = resamplings,
-      measures = measures, show.info = show.info),
+      measures = measures, keep.pred = keep.pred, models = models, show.info = show.info),
     level = plevel
   )
-  results.by.task = split(results, unlist(inds$task))
-  for(taskname in names(results.by.task)) {
-    names(results.by.task[[taskname]]) = inds$learner[inds$task == taskname]
+  results.by.task = split(results, unlist(grid$task))
+  for (taskname in names(results.by.task)) {
+    names(results.by.task[[taskname]]) = grid$learner[grid$task == taskname]
   }
   addClasses(results.by.task, "BenchmarkResult")
+  makeS3Obj("BenchmarkResult",
+    results = results.by.task,
+    measures = measures,
+    learners = learners
+  )
 }
 
-#' Result of a benchmark run.
-#'
-#' Container for results of benchmarked experiments using \code{\link{benchmark}}.
-#' The structure of the object itself is rather complicated, it is recommended to
-#' retrive required information via the \code{getBMR*} getter functions.
-#' You can also convert the object using \code{\link[base]{as.data.frame}}.
-#'
+#' @title BenchmarkResult object.
 #' @name BenchmarkResult
 #' @rdname BenchmarkResult
+#' @description
+#' Result of a benchmark experiment conducted by \code{\link{benchmark}}
+#' with the following members:
+#' \describe{
+#' \item{results [list of \code{\link{ResampleResult}}]:}{
+#'   A nested \code{list} of resample results,
+#'   first ordered by task id, then by learner id.
+#' }
+#' \item{measures [list of \code{\link{Measure}}]:}{
+#'   The performance measures used in the benchmark experiment.
+#' }
+#' \item{learners [list of \code{\link{Learner}}]:}{
+#'   The learning algorithms compared in the benchmark experiment.
+#' }
+#' }
+#'
+#' The print method of this object shows aggregated performance values
+#' for all tasks and learners.
+#'
+#' It is recommended to
+#' retrieve required information via the \code{getBMR*} getter functions.
+#' You can also convert the object using \code{\link[base]{as.data.frame}}.
+#'
 #' @family benchmark
 NULL
 
-benchmarkParallel = function(index, learners, tasks, resamplings, measures, keep.pred = TRUE, show.info) {
+benchmarkParallel = function(task, learner, learners, tasks, resamplings, measures, keep.pred = TRUE, models = TRUE, show.info) {
   setSlaveOptions()
-  ind.task = index[[1L]]
-  ind.learner = index[[2L]]
   if (show.info)
-    messagef("Task: %s, Learner: %s", ind.task, ind.learner)
-  cl = class(learners[[ind.learner]])
+    messagef("Task: %s, Learner: %s", task, learner)
+  cl = class(learners[[learner]])
   if("FeatSelWrapper" %in% cl) {
     extract.this = getFeatSelResult
   } else if("TuneWrapper" %in% cl) {
@@ -116,15 +152,14 @@ benchmarkParallel = function(index, learners, tasks, resamplings, measures, keep
   } else {
     extract.this = function(model) { NULL }
   }
-  lrn = learners[[ind.learner]]
-  r = resample(learners[[ind.learner]], tasks[[ind.task]], resamplings[[ind.task]],
-    measures = measures, models = TRUE, extract = extract.this, keep.pred = keep.pred, show.info = show.info)
+  lrn = learners[[learner]]
+  r = resample(learners[[learner]], tasks[[task]], resamplings[[task]],
+    measures = measures, models = models, extract = extract.this, keep.pred = keep.pred, show.info = show.info)
   # store used learner in result
   r$learner = lrn
   return(r)
 }
 
-
 #' @export
 print.BenchmarkResult = function(x, ...) {
   print(getBMRAggrPerformances(x, as.df = TRUE))
@@ -134,4 +169,3 @@ print.BenchmarkResult = function(x, ...) {
 as.data.frame.BenchmarkResult = function(x, ...) {
   getBMRPerformances(x, as.df = TRUE)
 }
-
