@@ -219,14 +219,14 @@ plotLearnerPrediction = function(learner, task, features = NULL, measures, cv =
       # plot background from model / grid
       p = ggplot(mapping = aes_string(x = x1n, y = x2n))
       p = p + geom_tile(data = grid, mapping = aes_string(fill = target))
-      p = p + scale_fill_gradient2(low = bg.cols[1L], mid = bg.cols[2L], high = bg.cols[3L])
+      p = p + scale_fill_gradient2(low = bg.cols[1L], mid = bg.cols[2L], high = bg.cols[3L], space = "Lab")
       # plot point, with circle and interior color for y
       p = p + geom_point(data = data, mapping = aes_string(x = x1n, y = x2n, colour = target),
         size = pointsize)
       p = p + geom_point(data = data, mapping = aes_string(x = x1n, y = x2n),
         size = pointsize, colour = "black", shape = 1)
       # plot point, with circle and interior color for y
-      p = p + scale_colour_gradient2(low = bg.cols[1L], mid = bg.cols[2L], high = bg.cols[3L])
+      p = p + scale_colour_gradient2(low = bg.cols[1L], mid = bg.cols[2L], high = bg.cols[3L], space = "Lab")
       p  = p + guides(colour = FALSE)
     }
   }
