@@ -67,8 +67,16 @@ selectFeaturesSequential = function(learner, task, resampling, measures, bit.nam
     stop(paste("Unknown method:", method))
   )
   res = evalOptimizationState(learner, task, resampling, measures, NULL, bits.to.features, control, opt.path, show.info, 1L, x, FALSE)
+  # add stuff to opt.path
   state = list(x = x, y = res$y)
-  addOptPathEl(opt.path, x = as.list(x), y = res$y, dob = 1L, eol = 2L, exec.time = res$exec.time, error.message = res$errmsg)
+  if (control$tune.threshold) {
+    # add class names to threshold, if longer than 1
+    extra = as.list(res$threshold)
+    names(extra) = paste0("threshold", ifelse(length(extra) > 1L, ".", ""), names(extra))
+  } else {
+    extra = NULL
+  }
+  addOptPathEl(opt.path, x = as.list(x), y = res$y, dob = 1L, eol = 2L, exec.time = res$exec.time, error.message = res$errmsg, extra = extra)
 
   forward = (method %in% c("sfs", "sffs"))
   fail = 0
