@@ -5,9 +5,10 @@
 #'
 #' @template arg_learner
 #' @template arg_task
-#' @param subset [\code{integer}]\cr
+#' @param subset [\code{integer} | \code{integer}]\cr
 #'   An index vector specifying the training cases to be used for fitting.
 #'   By default the complete data set is used.
+#'   Logical vectors will be transformed to integer with \code{\link[base]{which}}.
 #' @param weights [\code{numeric}]\cr
 #'   Optional, non-negative case weight vector to be used during fitting.
 #'   If given, must be of same length as \code{subset} and in corresponding order.
@@ -34,15 +35,18 @@ train = function(learner, task, subset, weights = NULL) {
   learner = checkLearner(learner)
   assertClass(task, classes = "Task")
   if (missing(subset)) {
-    subset = seq_len(task$task.desc$size)
+    subset = seq_len(getTaskSize(task))
   } else {
-    subset = asInteger(subset)
+    if (is.logical(subset))
+      subset = which(subset)
+    else
+      subset = asInteger(subset)
   }
 
   # make sure that pack for learner is loaded, probably needed when learner is exported
   requireLearnerPackages(learner)
 
-  tn = task$task.desc$target
+  tn = getTaskTargetNames(task)
 
   # make pars list for train call
   pars = list(.learner = learner, .task = task, .subset = subset)
@@ -51,7 +55,7 @@ train = function(learner, task, subset, weights = NULL) {
   if (!is.null(weights)) {
     assertNumeric(weights, len = length(subset), any.missing = FALSE, lower = 0)
   } else {
-    weights = task$weights
+    weights = getTaskWeights(task)
   }
 
   checkLearnerBeforeTrain(task, learner, weights)
@@ -64,7 +68,7 @@ train = function(learner, task, subset, weights = NULL) {
   # no vars? then use no vars model
 
   if (length(vars) == 0L) {
-    learner.model = makeNoFeaturesModel(targets = task$env$data[subset, tn], task.desc = task$task.desc)
+    learner.model = makeNoFeaturesModel(targets = task$env$data[subset, tn], task.desc = getTaskDescription(task))
     time.train = 0
   } else {
     opts = getLearnerOptions(learner, c("show.learner.output", "on.learner.error", "on.learner.warning"))
@@ -88,5 +92,5 @@ train = function(learner, task, subset, weights = NULL) {
     time.train = as.numeric(st[3L])
   }
   factor.levels = getTaskFactorLevels(task)
-  makeWrappedModel(learner, learner.model, task$task.desc, subset, vars, factor.levels, time.train)
+  makeWrappedModel(learner, learner.model, getTaskDescription(task), subset, vars, factor.levels, time.train)
 }
