@@ -2,7 +2,7 @@ context("downsample")
 
 test_that("downsample",  {
   down.tsk = downsample(multiclass.task, perc = 1/3)
-  expect_equal(down.tsk$task.desc$size, 50L)
+  expect_equal(getTaskSize(down.tsk), 50L)
   rsm.methods = c("Bootstrap", "Subsample", "Holdout")
   for(rsm.method in rsm.methods) {
     rin = makeResampleInstance(rsm.method, task = binaryclass.task)
@@ -23,4 +23,11 @@ test_that("downsample wrapper",  {
   expect_true(!is.na(r$aggr))
 })
 
+test_that("downsample wrapper works with xgboost, we had issue #492",  {
+  rdesc = makeResampleDesc("CV", iters = 2)
+  lrn = makeDownsampleWrapper("classif.xgboost", dw.perc = 0.5)
+  expect_output(print(lrn), "down")
+  r = resample(lrn, binaryclass.task, rdesc)
+  expect_true(!is.na(r$aggr))
+})
 
