@@ -61,7 +61,7 @@ test_that("show info works in selectFeatures", {
 # we had a bug here when an empty model was created and isFailureModel could not be called on it, cf. #284
 test_that("selectFeatures/sfs works with wrapper" , {
   ctrl = makeFeatSelControlSequential(method = "sfs")
-  lrn1 = makeLearner("classif.LiblineaRLogReg")
+  lrn1 = makeLearner("classif.LiblineaRL2LogReg")
   lrn2 = makeWeightedClassesWrapper(lrn1, wcw.param = "wi")
   task = subsetTask(binaryclass.task, features = getTaskFeatureNames(binaryclass.task)[1:2])
   rdesc = makeResampleDesc("Holdout", split = 0.8, stratify = TRUE)
