@@ -1,7 +1,7 @@
 context("cluster_FarthestFirst")
 
 test_that("cluster_FarthestFirst", {
-  library(RWeka)
+  requirePackages("RWeka", default.method = "load")
   parset.list = list(
     list(N=3)
   )
@@ -10,9 +10,9 @@ test_that("cluster_FarthestFirst", {
 
   for (i in 1:length(parset.list)) {
     parset = parset.list[[i]]
-    ctrl = do.call(Weka_control, parset)
+    ctrl = do.call(RWeka::Weka_control, parset)
     set.seed(getOption("mlr.debug.seed"))
-    m = FarthestFirst(noclass.train, control = ctrl)
+    m = RWeka::FarthestFirst(noclass.train, control = ctrl)
     p = predict(m, noclass.test) + 1
     old.predicts.list[[i]] = p
   }
