@@ -6,7 +6,7 @@ test_that("tuneThreshold", {
   lrn = makeLearner("classif.lda", predict.type="prob")
   m = train(lrn, binaryclass.task)
   p = predict(m, binaryclass.task)
-  tr = tuneThreshold(p, mmce)
+  tr = tuneThreshold(p)
   expect_true(length(tr$th) == 1 && tr$th >= 0 && tr$th <= 1)
   expect_true(tr$perf >= 0 && tr$perf < 0.3)
 
